# Changelog

## Version 0.1.0 (2024-06-24)

- Initial release
- Implemented basic image compositing functionality
- Added support for multiple masks and inverted masks
- Implemented mask normalization with adjustable levels
- Added asynchronous image writing
- Created command-line interface